<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "JUnit Report.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="Utils/Misc.xsl" />
	<xsl:import href="Detailed%20Report.xsl" />

	<xsl:param name="contextName" />
	<xsl:param name="title" select="tokenize($contextName,'/')[last()]" />

	<xsl:output method="xml" encoding="UTF-8" indent="yes" />

	<!-- externalisations -->
	<xsl:variable name="junitReport.errorMessage">
		<xsl:text>&junitReport.errorMessage;</xsl:text>
	</xsl:variable>
	<xsl:variable name="junitReport.errorType">
		<xsl:text>&junitReport.errorType;</xsl:text>
	</xsl:variable>
	<xsl:variable name="junitReport.failureMessage">
		<xsl:text>&junitReport.failureMessage;</xsl:text>
	</xsl:variable>
	<xsl:variable name="junitReport.failureType">
		<xsl:text>&junitReport.failureType;</xsl:text>
	</xsl:variable>

	<xsl:template match="/">

		<xsl:variable name="suiteName">
			<xsl:value-of select="$contextName" />
		</xsl:variable>

		<xsl:variable name="results"
			select="document(TestSuite/task/@logLocation)/Test/summary" />

		<xsl:variable name="totalTests" select="count($results)" />

		<xsl:variable name="testsFailed"
			select="count($results[@overallStatus='Failed'])" />

		<xsl:variable name="totalDuration" select="TestSuite/@duration div 1000" />

		<testsuite failures="{$testsFailed}" name="{$suiteName}"
			tests="{$totalTests}" time="{$totalDuration}">

			<xsl:call-template name="testRuns">
				<xsl:with-param name="results" select="$results" />
			</xsl:call-template>

		</testsuite>

	</xsl:template>

	<xsl:template name="testRuns">
		<xsl:param name="results" />

		<xsl:for-each select="TestSuite/task">

			<xsl:variable name="testName">
				<xsl:value-of select="tokenize(@name, '/')[last()]" />
			</xsl:variable>

			<xsl:variable name="logLocation">
				<xsl:value-of select="@logLocation" />
			</xsl:variable>

			<xsl:for-each select="document(@logLocation)/Test">

				<xsl:variable name="testPath">
					<xsl:value-of select="@testPath" />
				</xsl:variable>

				<xsl:variable name="testDurationMillis">
					<xsl:call-template name="getTestExecutionTime" />
				</xsl:variable>

				<xsl:variable name="testDuration">
					<xsl:value-of select="$testDurationMillis div 1000" />
				</xsl:variable>

				<testcase classname="{$testPath}" name="{$testName}" time="{$testDuration}">
					<xsl:if test="summary/@overallStatus='Failed'">
						<xsl:choose>
							<xsl:when test="summary/@errorMessages>0">
								<error message="{$junitReport.errorMessage}" type="{$junitReport.errorType}" />
							</xsl:when>
							<xsl:otherwise>
								<failure message="{$junitReport.failureMessage}" type="{$junitReport.failureType}" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
				</testcase>

			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
