--
-- Migrate database from schema version 1.9.20 to 1.9.21
--
DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.20';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--
ALTER TABLE `detail_execution` RENAME `de`;
CREATE TABLE `detail_execution`(
    `execution_id`         BIGINT          NOT NULL,
    `appmodelitem_id`      BIGINT          NOT NULL,
    `action_execution_id`  BIGINT,
    `status_id`            BIGINT,
    `username`             VARCHAR(50),
    `hostname`             VARCHAR(100),
    `total_iterations`     BIGINT,
    `failed_iterations`    VARCHAR(500),
    `failed_count`         BIGINT,
    PRIMARY KEY (`execution_id`), 
    INDEX `status_id`(`status_id`),
    INDEX `appmodelitem_id`(`appmodelitem_id`),
    INDEX `action_execution_id`(`action_execution_id`), 
    FOREIGN KEY (`action_execution_id`)
    REFERENCES `action_execution`(`id`),
    FOREIGN KEY (`status_id`)
    REFERENCES `status`(`id`),
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

INSERT INTO `detail_execution` SELECT * FROM `de`;
commit;
DROP TABLE `de`;

ALTER TABLE `scenario_execution` RENAME `se`;
CREATE TABLE `scenario_execution`(
    `execution_id`  BIGINT    NOT NULL,
    `scenario_id`   BIGINT    NOT NULL,
    PRIMARY KEY (`execution_id`), 
    INDEX `ref80117`(`execution_id`),
    INDEX `ref81118`(`scenario_id`), 
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`scenario_id`)
    REFERENCES `scenario`(`id`)
)ENGINE=INNODB
;

INSERT INTO `scenario_execution` SELECT * FROM `se`;
commit;
DROP TABLE `se`;

ALTER TABLE `execution_label` RENAME `el`;
CREATE TABLE `execution_label` (
`execution_id` BIGINT   NOT NULL, 
`label`        TEXT     NOT NULL, 
PRIMARY KEY (`execution_id`), 
FOREIGN KEY (`execution_id`)
REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

INSERT INTO `execution_label` SELECT * FROM `el`;
commit;
DROP TABLE `el`;

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.21');

commit;

  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;
