--
-- Migrate database from schema version 1.9.24.c to 1.9.24.d
--

DECLARE 
  required_version VARCHAR2(100);
  current_version VARCHAR2(100);
  index_not_exists EXCEPTION;
PRAGMA EXCEPTION_INIT(index_not_exists, -1418);
BEGIN
  SELECT '1.9.24.c' INTO required_version FROM dual;
  SELECT value INTO current_version FROM db_details 
    WHERE property='schema.version.number' 
    AND ctime = (
      SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number' 
    );
    
   IF current_version != required_version THEN
     RAISE_APPLICATION_ERROR( -20001, 
                             'Incorrect schema version: ' || current_version  ||
                             ', expected: ' || required_version );
                             
   ELSE

EXECUTE IMMEDIATE 'ALTER TABLE EMS_ROUTE_MRV MODIFY IBC NUMBER(19,0)';
EXECUTE IMMEDIATE 'ALTER TABLE EMS_ROUTE_MRV MODIFY OBC NUMBER(19,0)';

EXECUTE IMMEDIATE 'ALTER TABLE EMS_ROUTE_TS MODIFY IBC NUMBER(19,0)';
EXECUTE IMMEDIATE 'ALTER TABLE EMS_ROUTE_TS MODIFY OBC NUMBER(19,0)';

EXECUTE IMMEDIATE 'create or replace TRIGGER LOGMEASUREMENT_SEQ_TS_PRE_INS'
|| ' before insert on LOGMEASUREMENT_TS for each row'
|| ' begin '
|| ' if :new.IDX is null then '
|| ' select logmeasurement_ts_seq.nextval into :new.IDX from dual; '
|| ' end if; ' 
|| ' end;';

EXECUTE IMMEDIATE 'ALTER TRIGGER "LOGMEASUREMENT_SEQ_TS_PRE_INS" ENABLE';

EXECUTE IMMEDIATE 'create or replace TRIGGER COUNTER_DETAILS_SEQ_PRE_INS'
|| ' before insert on COUNTER_DETAILS for each row'
|| ' begin'
|| ' if :new.ID is null then'
|| ' select counter_details_seq.nextval into :new.ID from dual;'
|| ' end if;'
|| ' end;';

EXECUTE IMMEDIATE 'ALTER TRIGGER "COUNTER_DETAILS_SEQ_PRE_INS" ENABLE';

EXECUTE IMMEDIATE 'ALTER TABLE SUITE_EXECUTION ADD "EXPIRATION" NUMBER(20,0) NULL';
EXECUTE IMMEDIATE 'CREATE INDEX "SUITE_EXECUTION_EXP_INDEX" ON "SUITE_EXECUTION" ("EXPIRATION")';

EXECUTE IMMEDIATE 'CREATE OR REPLACE FORCE VIEW  "SCENARIO_EXECUTIONS" ("EXECUTION_ID", "LABEL", "LOCKBY", "LOCKDATE", "NOTES_PK", "PROJECT_PK", "SUITE_PK", "SUITE_ID", "SUITE_NAME", "SCENARIO_NAME", "SCENARIO_ID", "START_TIME", "END_TIME", "STATUS", "EXPIRES", "ROOT_EXEC_ID") AS 
  SELECT sce.execution_id, l.label, u.username, u.time, n.execution_id, t.project_id, t.id, t.uniqueid, t.display, s.display, s.uniqueid, e.start_time, e.end_time, (SELECT display FROM status WHERE id = e.status_id), t.expiration, e.root_id
  FROM scenario s, scenario_execution sce, execution e
  LEFT OUTER JOIN execution_label l ON e.id = l.execution_id
  LEFT OUTER JOIN (
    SELECT sue.execution_id, app.id, app.uniqueid, app.display, app.project_id, sue.expiration
    FROM suite_execution sue, appmodelitem app
    WHERE sue.appmodelitem_id = app.id
  ) t ON e.id = t.execution_id
  LEFT OUTER JOIN (
    SELECT el.execution_id, p.username, el.time
    FROM execution_lock el, person p
    WHERE el.person_id = p.id
  ) u ON e.id = u.execution_id
  LEFT OUTER JOIN execution_note n ON e.id = n.execution_id
  WHERE e.id = sce.execution_id AND sce.scenario_id = s.id';

INSERT INTO db_details VALUES
   ( (SELECT sysdate FROM dual), 'schema.version.number','1.9.24.d');

commit;

   END IF; -- version check
END;
/